# Generated by roxygen2: do not edit by hand

export(ggstratify)
import(data.table)
import(ggplot2)
import(shiny)
importFrom(grDevices,svg)
importFrom(patchwork,wrap_plots)
importFrom(stats,setNames)
importFrom(survival,Surv)
importFrom(survival,survfit)
importFrom(utils,head)
importFrom(utils,modifyList)
